@@ -33,7 +33,7 @@ from pybufrkit.errors import (BitReadError,
                               UnknownDescriptor,
                               PyBufrKitError)
 
-__version__ = '0.2.17'
+__version__ = '0.2.18'
 __author__ = 'ywangd@gmail.com'
 
 LOGGER = logging.getLogger('PyBufrKit')
@@ -107,7 +107,9 @@ def main():
     encode_parser.add_argument('output_filename',
                                metavar='output_file',
                                nargs='?', default='out.bufr',
-                               help='The output BUFR file, default out.bufr')
+                               help='The output BUFR file, default to out.bufr')
+    encode_parser.add_argument('--append', action='store_true',
+                               help='Append to the end of the output file')
     encode_parser.add_argument('-j', '--json', action='store_true',
                                help='The input is in JSON format')
     encode_parser.add_argument('-a', '--attributed', action='store_true',
@@ -122,6 +124,8 @@ def main():
                                type=int,
                                help='The maximum number of compiled templates to cache. '
                                     'A value greater than 0 is needed to activate template compilation.')
+    encode_parser.add_argument('--preamble', type=str,
+                               help='A prefix string added to the beginning of the output file (with utf-8 encoding)')
 
     info_parser = subparsers.add_parser('info',
                                         help='Show BUFR file information')
