@@ -3,11 +3,6 @@ from __future__ import print_function
 
 import os
 import unittest
-import functools
-
-from six import PY3, binary_type, text_type
-# noinspection PyUnresolvedReferences
-from six.moves import range
 
 from pybufrkit.decoder import Decoder, generate_bufr_message
 
